==> v0.4.0-alpha.tar.gz: athena.fb-infra.uk/index.php <==
<!DOCTYPE html>
<html>
  <head>
    <?php include './page-blocks/headers.php';?>
    <title>Athena</title>

    <script src="/js/tiploc-finder.js" async></script>

  </head>

  <body>

    <!-- Popup Menu -->
    <?php require "./page-blocks/nav-menu.php";?>

    <!-- Main Content Begins -->
    <?php require "./page-blocks/title-image.php";?>

      <br>

      <input class="lookup-box" type="text" id="crs-lookup" name="crs-lookup" placeholder="Enter CRS/TIPLOC"/>
      <br>
      <button class="lookup-button" onclick="getTextEntry()">Lookup Departure Board</button>

      <br>
      <br>

    <h2>Quick Links</h2>
      <button class="actionbutton" onclick="gotoInfoBoard('bathspa')">BTH</button>
      <button class="actionbutton" onclick="gotoInfoBoard('brstltm')">BRI</button>
      <button class="actionbutton" onclick="gotoInfoBoard('brstpwy')">BPW</button>
      <button class="actionbutton" onclick="gotoInfoBoard('crdfcen')">CDF</button>
      <button class="actionbutton" onclick="gotoInfoBoard('gloster')">GCR</button>
      <button class="actionbutton" onclick="gotoInfoBoard('oldfldp')">OLF</button>
      <button class="actionbutton" onclick="gotoInfoBoard('soton')">SOU</button>
      <button class="actionbutton" onclick="gotoInfoBoard('wstbryw')">WSB</button>
      <button class="actionbutton" onclick="gotoInfoBoard('wsmare')">WSM</button>

      <br>
      <br>
      <div class="text-description">
        <p>This is an Alpha release and is under testing.</p>
        <p>Some features may not work and some stations may not be available.</p>
      </div>

    <!-- Footer -->
    <?php include "./page-blocks/footer.php" ?>

  </body>

</html>

==> v0.4.4-alpha.tar.gz: athena.fb-infra.uk/index.php <==
<!DOCTYPE html>
<html>
  <head>
    <?php include './page-blocks/headers.php';?>
    <title>Athena</title>

    <script src="/js/tiploc-finder.js" async></script>

  </head>

  <body>

    <!-- Popup Menu -->
    <?php include "./page-blocks/nav-menu.php";?>

    <!-- Main Content Begins -->
    <?php include "./page-blocks/title-image.php";?>

    <br>
    <br>
    <br>
    <br>
    <input class="lookup-box" type="text" id="crs-lookup" name="crs-lookup" placeholder="Enter CRS/TIPLOC"/>
    <br>
    <button class="lookup-button" onclick="getTextEntry()">Lookup Departure Board</button>
    <br>
    <br>
    
    <h2 hidden>Server Maintenance</h2>
      <p hidden>Athena may be completely or partially unavailable between 1900-2300 on 07/10/2022, 
         apologies for any inconvinience caused to you.</p>

    <h2>Quick Links</h2>
      <button class="actionbutton" onclick="gotoInfoBoard('bathspa')">BTH</button>
      <button class="actionbutton" onclick="gotoInfoBoard('brstltm')">BRI</button>
      <button class="actionbutton" onclick="gotoInfoBoard('brstpwy')">BPW</button>
      <button class="actionbutton" onclick="gotoInfoBoard('crdfcen')">CDF</button>
      <button class="actionbutton" onclick="gotoInfoBoard('gloster')">GCR</button>
      <button class="actionbutton" onclick="gotoInfoBoard('oldfldp')">OLF</button>
      <button class="actionbutton" onclick="gotoInfoBoard('soton')">SOU</button>
      <button class="actionbutton" onclick="gotoInfoBoard('wstbryw')">WSB</button>
      <button class="actionbutton" onclick="gotoInfoBoard('wsmare')">WSM</button>

      <br>
      <br>
      <div class="text-description">
        <p>This is an Alpha release and is under testing.</p>
        <p>Some features may not work and some stations may not be available.</p>
      </div>

    <!-- Footer -->
    <?php include "./page-blocks/footer.php";?>

  </body>

</html>
